@@ -1,5 +1,8 @@
+#' @srrstats {EA6.0} return values are tested in tests
+
 univariate_normal_draws <- example_powerscale_model()$draws
 
+#' @srrstats {EA4.0} output type tested
 test_that("priorsense_data is created", {
   expect_s3_class(
     create_priorsense_data(
@@ -11,6 +14,7 @@ test_that("priorsense_data is created", {
 )
 
 #' @srrstats {G5.3} Missing values tested
+#' @srrstats {EA4.0} output type tested
 test_that("powerscale returns powerscaled_draws with no missing values", {
   psp <- powerscale(
       x = univariate_normal_draws,
@@ -38,6 +42,7 @@ test_that("powerscale returns powerscaled_draws with no missing values", {
 }
 )
 
+#' @srrstats {EA4.0} output type tested
 test_that("powerscale_seqence returns powerscaled_sequence", {
   expect_s3_class(
     suppressWarnings(powerscale_sequence(
@@ -48,13 +53,26 @@ test_that("powerscale_seqence returns powerscaled_sequence", {
 }
 )
 
-test_that("powerscale_sensitivity returns powerscaled_sensitivity_summary", {
-  expect_s3_class(
-    powerscale_sensitivity(
+#' @srrstats {EA6.0a} classes tested
+#' @srrstats {EA6.0b} dimensions tested
+#' @srrstats {EA6.0c} column names tested
+#' @srrstats {EA6.0d} classes of columns tested
+test_that("powerscale_sensitivity returns powerscaled_sensitivity_summary with expected columns", {
+  ps <- powerscale_sensitivity(
       x = univariate_normal_draws
-    ),
+    )
+  expect_s3_class(ps
+,
     "powerscaled_sensitivity_summary"
   )
+
+  expect_equal(dim(ps), c(2, 4))
+  
+  expect_identical(colnames(ps), c("variable", "prior", "likelihood", "diagnosis"))
+  expect_vector(ps[["variable"]], ptype = character())
+  expect_vector(ps[["prior"]], ptype = numeric())
+  expect_vector(ps[["likelihood"]], ptype = numeric())
+  expect_vector(ps[["diagnosis"]], ptype = character())
 }
 )
 
@@ -86,7 +104,9 @@ test_that("powerscale_sequence uses input alphas correctly", {
   )
 
   expect_equal(
-    get_powerscaling_details(pss$prior_scaled$draws_sequence[[length(pss$alphas)]])$alpha,
+    get_powerscaling_details(
+      pss$prior_scaled$draws_sequence[[length(pss$alphas)]]
+    )$alpha,
     2.5
   )
 
@@ -106,12 +126,17 @@ test_that("powerscale_sequence adapts alphas and keeps pareto-k low", {
   ))
 
   expect_lt(
-    get_powerscaling_details(pss$likelihood_scaled$draws_sequence[[1]])$diagnostics$khat,
+    get_powerscaling_details(
+      pss$likelihood_scaled$draws_sequence[[1]]
+    )$diagnostics$khat,
     k_threshold
   )
 
   expect_lt(
-    get_powerscaling_details(pss$likelihood_scaled$draws_sequence[[length(pss$likelihood_scaled$draws_sequence)]])$diagnostics$khat,
+    get_powerscaling_details(
+      pss$likelihood_scaled$draws_sequence[[length(
+        pss$likelihood_scaled$draws_sequence)]]
+    )$diagnostics$khat,
     k_threshold
   )
 
@@ -121,7 +146,9 @@ test_that("powerscale_sequence adapts alphas and keeps pareto-k low", {
   )
 
   expect_lt(
-    get_powerscaling_details(pss$prior_scaled$draws_sequence[[length(pss$prior_scaled$draws_sequence)]])$diagnostics$khat,
+    get_powerscaling_details(pss$prior_scaled$draws_sequence[[
+      length(pss$prior_scaled$draws_sequence)]]
+      )$diagnostics$khat,
     k_threshold
   )
 
@@ -155,7 +182,8 @@ test_that("powerscale_sequence gives symmetric range", {
   )
   
   expect_equal(
-    get_powerscaling_details(pss$prior_scaled$draws_sequence[[length(pss$alphas)]])$alpha,
+    get_powerscaling_details(pss$prior_scaled$draws_sequence[[
+      length(pss$alphas)]])$alpha,
     1 / lower_alpha
   )
   
@@ -172,7 +200,8 @@ test_that("powerscale_sequence gives symmetric range", {
 }
 )
 
-#' @srrstats {G5.9a} Adding trivial noise to data does not meaningfully change results*
+#' @srrstats {G5.9a} Adding trivial noise to data does not
+#'   meaningfully change results*
 test_that("small variation in draws does not affect result", {
 
   adjusted_draws <- univariate_normal_draws + .Machine$double.eps
@@ -196,29 +225,53 @@ test_that("powerscaling with alpha < 0 is an error", {
 
 #' @srrstats {G5.8, G5.8a} test edge case zero-length data
 test_that("powerscaling zero draws is an error", {
-  zero_draws <- data.frame(mu = numeric(), log_lik = numeric(), lprior = numeric())
+  zero_draws <- data.frame(
+    mu = numeric(),
+    log_lik = numeric(),
+    lprior = numeric()
+  )
   expect_error(powerscale(zero_draws, component = "prior", alpha = 0.1))
 }
 )
 
-#' @srrstats {G5.2a, G5.2b, G5.8b} constant weights unsupported and give explicit error message
+#' @srrstats {G5.2a, G5.2b, G5.8b} constant weights unsupported and
+#'   give explicit error message
 test_that("powerscaling with constant loglik is an error", {
-  const_draws <- data.frame(mu = 1:100, log_lik = rep(1, times = 100), lprior = 1:100)
+  const_draws <- data.frame(
+    mu = 1:100,
+    log_lik = rep(1, times = 100),
+    lprior = 1:100
+  )
   expect_error(powerscale(const_draws, component = "likelihood", alpha = 0.1),
-               "Log likelihood is constant. Power-scaling will not work in this case")
+               paste0("Log likelihood is constant. ",
+                      "Power-scaling will not work in this case"
+               )
+               )
 }
 )
 
 test_that("powerscaling with constant lprior is an error", {
-  const_draws <- data.frame(mu = 1:100, lprior = rep(1, times = 100), log_lik = 1:100)
+  const_draws <- data.frame(
+    mu = 1:100,
+    lprior = rep(1, times = 100),
+    log_lik = 1:100
+  )
   expect_error(powerscale(const_draws, component = "prior", alpha = 0.1),
-               "Log prior is constant. Power-scaling will not work in this case")
-}
+               paste0(
+                 "Log prior is constant. ",
+                 "Power-scaling will not work in this case"
+               )
+               )
+  }
 )
 
 #' @srrstats {G5.8, G5.8c} test edge case with NAs
 test_that("powerscaling with NA weights is an error", {
-  na_draws <- data.frame(mu = 1:100, log_lik = rep(NA, times = 100), lprior = 1:100)
+  na_draws <- data.frame(
+    mu = 1:100,
+    log_lik = rep(NA, times = 100),
+    lprior = 1:100
+  )
   expect_error(powerscale(na_draws, component = "likelihood", alpha = 0.1))
 }
 )
